==> igniteui-webcomponents-core-3.2.4.tgz: package/esm2015/lib/ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelTemplateWidthRequestedEventArgsDescription } from "./ListPanelTemplateWidthRequestedEventArgsDescription";
/**
 * @hidden
 */
export let ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a == null) {
                ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.c(ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a);
            }
            if (a.g(ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.s(ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("DataRow", "Number:int");
            a.item("DataItemRef", "(w:DataItem,wf:DataItem)DataRef");
            a.item("Width", "Number:double");
        }
        static d(a) {
            ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.b(a);
            a.u("ListPanelTemplateWidthRequestedEventArgs", () => new ListPanelTemplateWidthRequestedEventArgsDescription());
            a.t("ListPanelTemplateWidthRequestedEventArgs", ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a);
        }
    }
    ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata, 'ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata');
    ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a = null;
    return ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelTemplateWidthRequestedEventArgsDescription } from "./ListPanelTemplateWidthRequestedEventArgsDescription";
/**
 * @hidden
 */
export let ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a == null) {
                ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.c(ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a);
            }
            if (a.j(ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("DataRow", "Number:int");
            a.item("DataItemRef", "(w:DataItem,wf:DataItem)DataRef");
            a.item("Width", "Number:double");
        }
        static d(a) {
            ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.b(a);
            a.aa("ListPanelTemplateWidthRequestedEventArgs", () => new ListPanelTemplateWidthRequestedEventArgsDescription());
            a.z("ListPanelTemplateWidthRequestedEventArgs", ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a);
        }
    }
    ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata, 'ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata');
    ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata.a = null;
    return ListPanelTemplateWidthRequestedEventArgsDescriptionMetadata;
})();
